@@ -9,8 +9,6 @@
 
 #include <boost/container/flat_map.hpp>
 
-#include <OpenEXR/half.h>
-
 #include <OpenImageIO/color.h>
 #include <OpenImageIO/imagebufalgo.h>
 #include <OpenImageIO/imagebufalgo_util.h>
@@ -19,7 +17,7 @@
 
 #include "imageio_pvt.h"
 
-#define MAKE_OCIO_VERSION_HEX(maj, min, patch)                                 \
+#define MAKE_OCIO_VERSION_HEX(maj, min, patch) \
     (((maj) << 24) | ((min) << 16) | (patch))
 
 #ifdef USE_OCIO
@@ -707,7 +705,7 @@ public:
     {
         if (channels > 3)
             channels = 3;
-        if (channels == 3) {
+        if (channels == 3 && chanstride == sizeof(float)) {
             for (int y = 0; y < height; ++y) {
                 char* d = (char*)data + y * ystride;
                 for (int x = 0; x < width; ++x, d += xstride) {
@@ -720,9 +718,11 @@ public:
         } else {
             for (int y = 0; y < height; ++y) {
                 char* d = (char*)data + y * ystride;
-                for (int x = 0; x < width; ++x, d += xstride)
-                    for (int c = 0; c < channels; ++c)
-                        ((float*)d)[c] = sRGB_to_linear(((float*)d)[c]);
+                for (int x = 0; x < width; ++x, d += xstride) {
+                    char* dc = d;
+                    for (int c = 0; c < channels; ++c, dc += chanstride)
+                        ((float*)dc)[c] = sRGB_to_linear(((float*)dc)[c]);
+                }
             }
         }
     }
@@ -742,7 +742,7 @@ public:
     {
         if (channels > 3)
             channels = 3;
-        if (channels == 3) {
+        if (channels == 3 && chanstride == sizeof(float)) {
             for (int y = 0; y < height; ++y) {
                 char* d = (char*)data + y * ystride;
                 for (int x = 0; x < width; ++x, d += xstride) {
@@ -755,9 +755,11 @@ public:
         } else {
             for (int y = 0; y < height; ++y) {
                 char* d = (char*)data + y * ystride;
-                for (int x = 0; x < width; ++x, d += xstride)
-                    for (int c = 0; c < channels; ++c)
-                        ((float*)d)[c] = linear_to_sRGB(((float*)d)[c]);
+                for (int x = 0; x < width; ++x, d += xstride) {
+                    char* dc = d;
+                    for (int c = 0; c < channels; ++c, dc += chanstride)
+                        ((float*)dc)[c] = linear_to_sRGB(((float*)dc)[c]);
+                }
             }
         }
     }
@@ -780,9 +782,11 @@ public:
             channels = 3;
         for (int y = 0; y < height; ++y) {
             char* d = (char*)data + y * ystride;
-            for (int x = 0; x < width; ++x, d += xstride)
-                for (int c = 0; c < channels; ++c)
+            for (int x = 0; x < width; ++x, d += xstride) {
+                char* dc = d;
+                for (int c = 0; c < channels; ++c, dc += chanstride)
                     ((float*)d)[c] = Rec709_to_linear(((float*)d)[c]);
+            }
         }
     }
 };
@@ -803,9 +807,11 @@ public:
             channels = 3;
         for (int y = 0; y < height; ++y) {
             char* d = (char*)data + y * ystride;
-            for (int x = 0; x < width; ++x, d += xstride)
-                for (int c = 0; c < channels; ++c)
+            for (int x = 0; x < width; ++x, d += xstride) {
+                char* dc = d;
+                for (int c = 0; c < channels; ++c, dc += chanstride)
                     ((float*)d)[c] = linear_to_Rec709(((float*)d)[c]);
+            }
         }
     }
 };
@@ -826,7 +832,7 @@ public:
     {
         if (channels > 3)
             channels = 3;
-        if (channels == 3) {
+        if (channels == 3 && chanstride == sizeof(float)) {
             simd::vfloat4 g = m_gamma;
             for (int y = 0; y < height; ++y) {
                 char* d = (char*)data + y * ystride;
@@ -840,9 +846,11 @@ public:
         } else {
             for (int y = 0; y < height; ++y) {
                 char* d = (char*)data + y * ystride;
-                for (int x = 0; x < width; ++x, d += xstride)
-                    for (int c = 0; c < channels; ++c)
+                for (int x = 0; x < width; ++x, d += xstride) {
+                    char* dc = d;
+                    for (int c = 0; c < channels; ++c, dc += chanstride)
                         ((float*)d)[c] = powf(((float*)d)[c], m_gamma);
+                }
             }
         }
     }
@@ -860,16 +868,16 @@ public:
     {
     }
     ~ColorProcessor_Ident() {}
-    virtual void apply(float* data, int width, int height, int channels,
-                       stride_t chanstride, stride_t xstride,
-                       stride_t ystride) const
+    virtual void apply(float* /*data*/, int /*width*/, int /*height*/,
+                       int /*channels*/, stride_t /*chanstride*/,
+                       stride_t /*xstride*/, stride_t /*ystride*/) const
     {
     }
 };
 
 
 
-// ColorProcessor that implements a matrix multiply color transfomation.
+// ColorProcessor that implements a matrix multiply color transformation.
 class ColorProcessor_Matrix : public ColorProcessor {
 public:
     ColorProcessor_Matrix(const Imath::M44f& Matrix, bool inverse)
@@ -886,7 +894,7 @@ public:
                        stride_t ystride) const
     {
         using namespace simd;
-        if (channels == 3) {
+        if (channels == 3 && chanstride == sizeof(float)) {
             for (int y = 0; y < height; ++y) {
                 char* d = (char*)data + y * ystride;
                 for (int x = 0; x < width; ++x, d += xstride) {
@@ -896,7 +904,7 @@ public:
                     xcolor.store((float*)d, 3);
                 }
             }
-        } else if (channels >= 4) {
+        } else if (channels >= 4 && chanstride == sizeof(float)) {
             for (int y = 0; y < height; ++y) {
                 char* d = (char*)data + y * ystride;
                 for (int x = 0; x < width; ++x, d += xstride) {
@@ -906,6 +914,20 @@ public:
                     xcolor.store((float*)d);
                 }
             }
+        } else {
+            channels = std::min(channels, 4);
+            for (int y = 0; y < height; ++y) {
+                char* d = (char*)data + y * ystride;
+                for (int x = 0; x < width; ++x, d += xstride) {
+                    vfloat4 color;
+                    char* dc = d;
+                    for (int c = 0; c < channels; ++c, dc += chanstride)
+                        color[c] = *(float*)dc;
+                    vfloat4 xcolor = color * m_M;
+                    for (int c = 0; c < channels; ++c, dc += chanstride)
+                        *(float*)dc = xcolor[c];
+                }
+            }
         }
     }
 
@@ -1054,7 +1076,7 @@ ColorConfig::createColorProcessor(ustring inputColorSpace,
 
 #ifdef USE_OCIO
     if (!handle && p) {
-        // If we found a procesor from OCIO, even if it was a NoOp, and we
+        // If we found a processor from OCIO, even if it was a NoOp, and we
         // still don't have a better idea, return it.
         handle = ColorProcessorHandle(new ColorProcessor_OCIO(p));
     }
@@ -1433,8 +1455,10 @@ colorconvert_impl(ImageBuf& R, const ImageBuf& A,
         [&, unpremult, channelsToCopy, processor](ROI roi) {
             int width = roi.width();
             // Temporary space to hold one RGBA scanline
-            vfloat4* scanline  = OIIO_ALLOCA(vfloat4, width);
-            float* alpha       = OIIO_ALLOCA(float, width);
+            vfloat4* scanline;
+            OIIO_ALLOCATE_STACK_OR_HEAP(scanline, vfloat4, width);
+            float* alpha;
+            OIIO_ALLOCATE_STACK_OR_HEAP(alpha, float, width);
             const float fltmin = std::numeric_limits<float>::min();
             ImageBuf::ConstIterator<Atype> a(A, roi);
             ImageBuf::Iterator<Rtype> r(R, roi);
@@ -1451,13 +1475,14 @@ colorconvert_impl(ImageBuf& R, const ImageBuf& A,
                         scanline[i] = v;
                     }
 
-                    // Optionally unpremult
+                    // Optionally unpremult. Be careful of alpha==0 pixels,
+                    // preserve their color rather than div-by-zero.
                     if (unpremult) {
                         for (int i = 0; i < width; ++i) {
                             float a  = extract<3>(scanline[i]);
-                            a        = a >= fltmin ? a : 1.0f;
                             alpha[i] = a;
-                            scanline[i] /= a;
+                            a        = a >= fltmin ? a : 1.0f;
+                            scanline[i] /= vfloat4(a,a,a,1.0f);
                         }
                     }
 
@@ -1466,10 +1491,14 @@ colorconvert_impl(ImageBuf& R, const ImageBuf& A,
                                      sizeof(float), 4 * sizeof(float),
                                      width * 4 * sizeof(float));
 
-                    // Optionally re-premult
+                    // Optionally re-premult. Be careful of alpha==0 pixels,
+                    // preserve their value rather than crushing to black.
                     if (unpremult) {
-                        for (int i = 0; i < width; ++i)
-                            scanline[i] *= alpha[i];
+                        for (int i = 0; i < width; ++i) {
+                            float a  = alpha[i];
+                            a        = a >= fltmin ? a : 1.0f;
+                            scanline[i] *= vfloat4(a,a,a,1.0f);
+                        }
                     }
 
                     // Store the scanline
@@ -1502,8 +1531,10 @@ colorconvert_impl_float_rgba(ImageBuf& R, const ImageBuf& A,
     parallel_image(roi, parallel_image_options(nthreads), [&](ROI roi) {
         int width = roi.width();
         // Temporary space to hold one RGBA scanline
-        vfloat4* scanline  = OIIO_ALLOCA(vfloat4, width);
-        float* alpha       = OIIO_ALLOCA(float, width);
+        vfloat4* scanline;
+        OIIO_ALLOCATE_STACK_OR_HEAP(scanline, vfloat4, width);
+        float* alpha;
+        OIIO_ALLOCATE_STACK_OR_HEAP(alpha, float, width);
         const float fltmin = std::numeric_limits<float>::min();
         for (int k = roi.zbegin; k < roi.zend; ++k) {
             for (int j = roi.ybegin; j < roi.yend; ++j) {
@@ -1515,12 +1546,12 @@ colorconvert_impl_float_rgba(ImageBuf& R, const ImageBuf& A,
                     for (int i = 0; i < width; ++i) {
                         vfloat4 p(scanline[i]);
                         float a  = extract<3>(p);
-                        a        = a >= fltmin ? a : 1.0f;
                         alpha[i] = a;
+                        a        = a >= fltmin ? a : 1.0f;
                         if (a == 1.0f)
                             scanline[i] = p;
                         else
-                            scanline[i] = p / a;
+                            scanline[i] = p / vfloat4(a, a, a, 1.0f);
                     }
                 }
 
@@ -1531,8 +1562,13 @@ colorconvert_impl_float_rgba(ImageBuf& R, const ImageBuf& A,
 
                 // Optionally premult
                 if (unpremult) {
-                    for (int i = 0; i < width; ++i)
-                        scanline[i] *= alpha[i];
+                    for (int i = 0; i < width; ++i) {
+                        vfloat4 p(scanline[i]);
+                        float a = alpha[i];
+                        a       = a >= fltmin ? a : 1.0f;
+                        p *= vfloat4(a, a, a, 1.0f);
+                        scanline[i] = p;
+                    }
                 }
                 memcpy(R.pixeladdr(roi.xbegin, j, k), scanline,
                        width * 4 * sizeof(float));
