@@ -139,10 +139,10 @@ catalog_plugin(const std::string& format_name,
             // It's ok if they're both the same file; just skip it.
             return;
         }
-        OIIO::debug("OpenImageIO WARNING: %s had multiple plugins:\n"
-                    "\t\"%s\"\n    as well as\n\t\"%s\"\n"
-                    "    Ignoring all but the first one.\n",
-                    format_name, found_path->second, plugin_fullpath);
+        OIIO::debugf("OpenImageIO WARNING: %s had multiple plugins:\n"
+                     "\t\"%s\"\n    as well as\n\t\"%s\"\n"
+                     "    Ignoring all but the first one.\n",
+                     format_name, found_path->second, plugin_fullpath);
         return;
     }
 
@@ -196,15 +196,19 @@ catalog_plugin(const std::string& format_name,
 // list of file extensions, for the standard plugins that come with OIIO.
 // These won't be used unless EMBED_PLUGINS is defined.  Use the PLUGENTRY
 // macro to make the declaration compact and easy to read.
-#    define PLUGENTRY(name)                                                    \
-        ImageInput* name##_input_imageio_create();                             \
-        ImageOutput* name##_output_imageio_create();                           \
-        extern const char* name##_output_extensions[];                         \
-        extern const char* name##_input_extensions[];                          \
+#    define PLUGENTRY(name)                            \
+        ImageInput* name##_input_imageio_create();     \
+        ImageOutput* name##_output_imageio_create();   \
+        extern const char* name##_output_extensions[]; \
+        extern const char* name##_input_extensions[];  \
         extern const char* name##_imageio_library_version();
-#    define PLUGENTRY_RO(name)                                                 \
-        ImageInput* name##_input_imageio_create();                             \
-        extern const char* name##_input_extensions[];                          \
+#    define PLUGENTRY_RO(name)                        \
+        ImageInput* name##_input_imageio_create();    \
+        extern const char* name##_input_extensions[]; \
+        extern const char* name##_imageio_library_version();
+#    define PLUGENTRY_WO(name)                         \
+        ImageOutput* name##_output_imageio_create();   \
+        extern const char* name##_output_extensions[]; \
         extern const char* name##_imageio_library_version();
 
 PLUGENTRY(bmp);
@@ -234,6 +238,7 @@ PLUGENTRY(rla);
 PLUGENTRY(sgi);
 PLUGENTRY(socket);
 PLUGENTRY_RO(softimage);
+PLUGENTRY_WO(term);
 PLUGENTRY(tiff);
 PLUGENTRY(targa);
 PLUGENTRY(webp);
@@ -266,6 +271,12 @@ catalog_builtin_plugins()
             #name, (ImageInput::Creator)name##_input_imageio_create,     \
             name##_input_extensions, nullptr, nullptr,                   \
             name##_imageio_library_version())
+#define DECLAREPLUG_WO(name)                                             \
+        declare_imageio_format(                                          \
+            #name, nullptr, nullptr,                                     \
+            (ImageOutput::Creator)name##_output_imageio_create,          \
+            name##_output_extensions,                                    \
+            name##_imageio_library_version())
 
 #if !defined(DISABLE_BMP)
     DECLAREPLUG (bmp);
@@ -374,6 +385,9 @@ catalog_builtin_plugins()
 #if !defined(DISABLE_TARGA)
     DECLAREPLUG (targa);
 #endif
+#if !defined(DISABLE_TERM)
+    DECLAREPLUG_WO (term);
+#endif
 #ifdef USE_WEBP
 #if !defined(DISABLE_WEBP)
     DECLAREPLUG (webp);
@@ -448,8 +462,8 @@ pvt::catalog_all_plugins(std::string searchpath)
 
 
 std::unique_ptr<ImageOutput>
-ImageOutput::create(const std::string& filename,
-                    const std::string& plugin_searchpath)
+ImageOutput::create(string_view filename, Filesystem::IOProxy* ioproxy,
+                    string_view plugin_searchpath)
 {
     std::unique_ptr<ImageOutput> out;
     if (filename.empty()) {  // Can't even guess if no filename given
@@ -475,7 +489,7 @@ ImageOutput::create(const std::string& filename,
         if (found == output_formats.end()) {
             catalog_all_plugins(plugin_searchpath.size()
                                     ? plugin_searchpath
-                                    : pvt::plugin_searchpath.string());
+                                    : string_view(pvt::plugin_searchpath));
             found = output_formats.find(format);
         }
         if (found != output_formats.end()) {
@@ -504,11 +518,31 @@ ImageOutput::create(const std::string& filename,
         // Safety in case the ctr throws an exception
         out.reset();
     }
+    if (out && ioproxy) {
+        if (!out->supports("ioproxy")) {
+            out.reset();
+            OIIO::pvt::errorf(
+                "ImageOutput::create called with IOProxy, but format %s does not support IOProxy",
+                out->format_name());
+        } else {
+            out->set_ioproxy(ioproxy);
+        }
+    }
     return out;
 }
 
 
 
+// DEPRECATED(2.2)
+std::unique_ptr<ImageOutput>
+ImageOutput::create(const std::string& filename,
+                    const std::string& plugin_searchpath)
+{
+    return create(filename, nullptr, plugin_searchpath);
+}
+
+
+
 void
 ImageOutput::destroy(ImageOutput* x)
 {
@@ -517,6 +551,7 @@ ImageOutput::destroy(ImageOutput* x)
 
 
 
+// DEPRECATED(2.1)
 std::unique_ptr<ImageInput>
 ImageInput::create(const std::string& filename,
                    const std::string& plugin_searchpath)
@@ -526,6 +561,7 @@ ImageInput::create(const std::string& filename,
 
 
 
+// DEPRECATED(2.1)
 std::unique_ptr<ImageInput>
 ImageInput::create(const std::string& filename, bool do_open,
                    const std::string& plugin_searchpath)
@@ -535,9 +571,19 @@ ImageInput::create(const std::string& filename, bool do_open,
 
 
 
+// DEPRECATED(2.2)
 std::unique_ptr<ImageInput>
 ImageInput::create(const std::string& filename, bool do_open,
                    const ImageSpec* config, string_view plugin_searchpath)
+{
+    return create(filename, do_open, config, nullptr, plugin_searchpath);
+}
+
+
+
+std::unique_ptr<ImageInput>
+ImageInput::create(string_view filename, bool do_open, const ImageSpec* config,
+                   Filesystem::IOProxy* ioproxy, string_view plugin_searchpath)
 {
     // In case the 'filename' was really a REST-ful URI with query/config
     // details tacked on to the end, strip them off so we can correctly
@@ -603,10 +649,13 @@ ImageInput::create(const std::string& filename, bool do_open,
         }
         ImageSpec tmpspec;
         bool ok = false;
-        if (in && config)
-            ok = in->open(filename, tmpspec, *config);
-        else if (in)
-            ok = in->open(filename, tmpspec);
+        if (in) {
+            in->set_ioproxy(ioproxy);
+            if (config)
+                ok = in->open(filename, tmpspec, *config);
+            else
+                ok = in->open(filename, tmpspec);
+        }
         if (ok) {
             // It worked
             if (!do_open)
@@ -652,7 +701,7 @@ ImageInput::create(const std::string& filename, bool do_open,
             }
             if (!in)
                 continue;
-            if (!do_open && !in->valid_file(filename)) {
+            if (!do_open && !ioproxy && !in->valid_file(filename)) {
                 // Since we didn't need to open it, we just checked whether
                 // it was a valid file, and it's not.  Try the next one.
                 in.reset();
@@ -660,6 +709,7 @@ ImageInput::create(const std::string& filename, bool do_open,
             }
             // We either need to open it, or we already know it appears
             // to be a file of the right type.
+            in->set_ioproxy(ioproxy);
             bool ok = in->open(filename, tmpspec, myconfig);
             if (ok) {
                 if (!do_open)
