@@ -19,14 +19,14 @@
 #include <OpenEXR/ImfTiledOutputFile.h>
 
 #ifdef OPENEXR_VERSION_MAJOR
-#    define OPENEXR_CODED_VERSION                                              \
-        (OPENEXR_VERSION_MAJOR * 10000 + OPENEXR_VERSION_MINOR * 100           \
+#    define OPENEXR_CODED_VERSION                                    \
+        (OPENEXR_VERSION_MAJOR * 10000 + OPENEXR_VERSION_MINOR * 100 \
          + OPENEXR_VERSION_PATCH)
 #else
 #    define OPENEXR_CODED_VERSION 20000
 #endif
 
-#if OPENEXR_CODED_VERSION >= 20400                                             \
+#if OPENEXR_CODED_VERSION >= 20400 \
     || __has_include(<OpenEXR/ImfFloatVectorAttribute.h>)
 #    define OPENEXR_HAS_FLOATVECTOR 1
 #else
@@ -35,9 +35,9 @@
 
 // The way that OpenEXR uses dynamic casting for attributes requires
 // temporarily suspending "hidden" symbol visibility mode.
-#ifdef __GNUC__
-#    pragma GCC visibility push(default)
-#endif
+OIIO_PRAGMA_VISIBILITY_PUSH
+OIIO_PRAGMA_WARNING_PUSH
+OIIO_GCC_PRAGMA(GCC diagnostic ignored "-Wunused-parameter")
 #include <OpenEXR/IexBaseExc.h>
 #include <OpenEXR/ImfBoxAttribute.h>
 #include <OpenEXR/ImfCRgbaFile.h>  // JUST to get symbols to figure out version!
@@ -56,10 +56,6 @@
 #include <OpenEXR/ImfTimeCodeAttribute.h>
 #include <OpenEXR/ImfVecAttribute.h>
 
-#ifdef __GNUC__
-#    pragma GCC visibility pop
-#endif
-
 #include <OpenEXR/ImfDeepScanLineOutputPart.h>
 #include <OpenEXR/ImfDeepTiledOutputPart.h>
 #include <OpenEXR/ImfDoubleAttribute.h>
@@ -68,6 +64,8 @@
 #include <OpenEXR/ImfPartType.h>
 #include <OpenEXR/ImfStringVectorAttribute.h>
 #include <OpenEXR/ImfTiledOutputPart.h>
+OIIO_PRAGMA_WARNING_POP
+OIIO_PRAGMA_VISIBILITY_POP
 
 #include <OpenImageIO/dassert.h>
 #include <OpenImageIO/deepdata.h>
@@ -137,6 +135,11 @@ public:
     virtual bool write_deep_tiles(int xbegin, int xend, int ybegin, int yend,
                                   int zbegin, int zend,
                                   const DeepData& deepdata) override;
+    virtual bool set_ioproxy(Filesystem::IOProxy* ioproxy) override
+    {
+        m_io = ioproxy;
+        return true;
+    }
 
 private:
     std::unique_ptr<OpenEXROutputStream>
@@ -221,8 +224,8 @@ OIIO_EXPORT int openexr_imageio_version = OIIO_PLUGIN_VERSION;
 OIIO_EXPORT const char*
 openexr_imageio_library_version()
 {
-#ifdef OPENEXR_PACKAGE_STRING
-    return OPENEXR_PACKAGE_STRING;
+#ifdef OPENEXR_VERSION_STRING
+    return "OpenEXR " OPENEXR_VERSION_STRING;
 #else
     return "OpenEXR 1.x";
 #endif
@@ -340,7 +343,8 @@ OpenEXROutput::open(const std::string& name, const ImageSpec& userspec,
         sanity_check_channelnames();
         const ParamValue* param = m_spec.find_attribute("oiio:ioproxy",
                                                         TypeDesc::PTR);
-        m_io = param ? param->get<Filesystem::IOProxy*>() : nullptr;
+        if (param)
+            m_io = param->get<Filesystem::IOProxy*>();
 
         if (!spec_to_header(m_spec, m_subimage, m_headers[m_subimage]))
             return false;
@@ -814,7 +818,8 @@ struct ExrMeta {
 static ExrMeta exr_meta_translation[] = {
     // Translate OIIO standard metadata names to OpenEXR standard names
     ExrMeta("worldtocamera", "worldToCamera", TypeMatrix),
-    ExrMeta("worldtoscreen", "worldToNDC", TypeMatrix),
+    ExrMeta("worldtoNDC", "worldToNDC", TypeMatrix),
+    ExrMeta("worldtoscreen", "worldToScreen", TypeMatrix),
     ExrMeta("DateTime", "capDate", TypeString),
     ExrMeta("ImageDescription", "comments", TypeString),
     ExrMeta("description", "comments", TypeString),
@@ -886,9 +891,9 @@ OpenEXROutput::put_parameter(const std::string& name, TypeDesc type,
             else if (Strutil::iequals(str, "b44a"))
                 header.compression() = Imf::B44A_COMPRESSION;
 #endif
-#if defined(OPENEXR_VERSION_MAJOR)                                             \
-    && (OPENEXR_VERSION_MAJOR * 10000 + OPENEXR_VERSION_MINOR * 100            \
-        + OPENEXR_VERSION_PATCH)                                               \
+#if defined(OPENEXR_VERSION_MAJOR)                                  \
+    && (OPENEXR_VERSION_MAJOR * 10000 + OPENEXR_VERSION_MINOR * 100 \
+        + OPENEXR_VERSION_PATCH)                                    \
            >= 20200
             else if (Strutil::iequals(str, "dwaa"))
                 header.compression() = Imf::DWAA_COMPRESSION;
@@ -968,7 +973,7 @@ OpenEXROutput::put_parameter(const std::string& name, TypeDesc type,
     // Now if we still don't match a specific type OpenEXR is looking for,
     // skip it.
     if (exrtype != TypeDesc() && !exrtype.equivalent(type)) {
-        OIIO::debug(
+        OIIO::debugf(
             "OpenEXR output metadata \"%s\" type mismatch: expected %s, got %s\n",
             name, exrtype, type);
         return false;
@@ -1236,12 +1241,12 @@ OpenEXROutput::put_parameter(const std::string& name, TypeDesc type,
 #endif
         }
     } catch (const std::exception& e) {
-        OIIO::debug("Caught OpenEXR exception: %s\n", e.what());
+        OIIO::debugf("Caught OpenEXR exception: %s\n", e.what());
     } catch (...) {  // catch-all for edge cases or compiler bugs
         OIIO::debug("Caught unknown OpenEXR exception\n");
     }
 
-    OIIO::debug("Don't know what to do with %s %s\n", type, xname);
+    OIIO::debugf("Don't know what to do with %s %s\n", type, xname);
     return false;
 }
 
@@ -1295,8 +1300,8 @@ OpenEXROutput::close()
 
 
 bool
-OpenEXROutput::write_scanline(int y, int z, TypeDesc format, const void* data,
-                              stride_t xstride)
+OpenEXROutput::write_scanline(int y, int /*z*/, TypeDesc format,
+                              const void* data, stride_t xstride)
 {
     if (!(m_output_scanline || m_scanline_output_part)) {
         errorf("called OpenEXROutput::write_scanline without an open file");
@@ -1554,7 +1559,7 @@ OpenEXROutput::write_tiles(int xbegin, int xend, int ybegin, int yend,
 
 
 bool
-OpenEXROutput::write_deep_scanlines(int ybegin, int yend, int z,
+OpenEXROutput::write_deep_scanlines(int ybegin, int yend, int /*z*/,
                                     const DeepData& deepdata)
 {
     if (m_deep_scanline_output_part == NULL) {
